@@ -232,23 +232,31 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
     QDateTime routeEnd;
 
     {
-        QRegExp regexp = QRegExp("<div class=\"querysummary2 (.*)\".*>.*([0-3][0-9]\\.[0-1][0-9]\\.[0-9][0-9]).*([0-9][0-9]:[0-9][0-9]).*-.*([0-3][0-9]\\.[0-1][0-9]\\.[0-9][0-9]).*([0-9][0-9]:[0-9][0-9]).*</div>");
+        //QRegExp regexp = QRegExp("<div class=\"querysummary2 (.*)\".*>.*([0-3][0-9]\\.[0-1][0-9]\\.[0-9][0-9]).*([0-9][0-9]:[0-9][0-9]).*-.*([0-3][0-9]\\.[0-1][0-9]\\.[0-9][0-9]).*([0-9][0-9]:[0-9][0-9]).*</div>");
+        QRegExp regexp = QRegExp("<span class=\"querysummary2\" id=\"(.*)\".*>.*([0-3][0-9]\\.[0-1][0-9]\\.[0-9][0-9]).*([0-9][0-9]:[0-9][0-9]).*-.*([0-3][0-9]\\.[0-1][0-9]\\.[0-9][0-9]).*([0-9][0-9]:[0-9][0-9]).*</span>");
         regexp.setMinimal(true);
         regexp.indexIn(xhtml);
+        qDebug() << "******" << regexp.cap(0);
+
         if (regexp.cap(0)!="")
         {
             qDebug() << "******" << regexp.cap(0);
             QDate date=QDate::fromString(regexp.cap(2).trimmed(),"dd.MM.yy");
             date = date.addYears(100);
+            qDebug() << "date: " << regexp.cap(2) << date;
             QTime time=QTime::fromString(regexp.cap(3).trimmed(),"hh:mm");
             routeStart=QDateTime(date,time);
+            qDebug() << "routestart: " << regexp.cap(3) << routeStart;
             date=QDate::fromString(regexp.cap(4).trimmed(),"dd.MM.yy");
             date = date.addYears(100);
+            qDebug() << "date: " << regexp.cap(4) << date;
             time=QTime::fromString(regexp.cap(5).trimmed(),"hh:mm");
             routeEnd=QDateTime(date,time);
+            qDebug() << "routeend: " << regexp.cap(5) << routeEnd;
         }
         else {
-            regexp.setPattern("<div class=\"querysummary2 (.*)\".*>.*([0-3][0-9]\\.[0-1][0-9]\\.[0-9][0-9]).*([0-9][0-9]:[0-9][0-9]).*\\-.*([0-9][0-9]:[0-9][0-9]).*</div>");
+            //regexp.setPattern("<div class=\"querysummary2 (.*)\".*>.*([0-3][0-9]\\.[0-1][0-9]\\.[0-9][0-9]).*([0-9][0-9]:[0-9][0-9]).*\\-.*([0-9][0-9]:[0-9][0-9]).*</div>");
+            regexp.setPattern("<span class=\"querysummary2\" id=\"(.*)\".*>.*([0-3][0-9]\\.[0-1][0-9]\\.[0-9][0-9]).*([0-9][0-9]:[0-9][0-9]).*\\-.*([0-9][0-9]:[0-9][0-9]).*</span>");
             regexp.indexIn(xhtml);
             if (regexp.cap(0)!="")
             {
@@ -266,6 +274,7 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
 
     //We use Regex to get each element details page
     QRegExp regexp = QRegExp("<div class=\"rline haupt (.*)\".*>(.*)</div>");
+
     regexp.setMinimal(true);
 
     int idx = 0;
@@ -277,7 +286,7 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
     while (idx >= 0)
     {
         idx = regexp.indexIn(xhtml, idx);
-        //qDebug() << "DB Mobile:" << idx;
+        qDebug() << "DB Mobile:" << idx;
         if (idx >= 0)
         {
             QString divType=regexp.cap(1);
@@ -298,6 +307,22 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
             element.replace(ahrefReg, "");
             element.replace("&nbsp;", " ");
 
+            //remove divs because of missing closing div
+            /*ahrefReg = QRegExp("</a>");
+            ahrefReg.setMinimal(true);
+            element.replace(ahrefReg, "</a></div>");*/
+            ahrefReg = QRegExp("<div class=\"interSection\">");
+            ahrefReg.setMinimal(true);
+            element.replace(ahrefReg, "");
+            ahrefReg = QRegExp("<div class=\"motSection\">");
+            ahrefReg.setMinimal(true);
+            element.replace(ahrefReg, "");
+            ahrefReg = QRegExp("compulsory reservation");
+            ahrefReg.setMinimal(true);
+            element.replace(ahrefReg, "</div>");
+
+            qDebug() << "element: " << element;
+
             readBuffer.setData(element.toAscii());
             readBuffer.open(QIODevice::ReadOnly);
 
@@ -310,6 +335,7 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
             {
                 qDebug() << "parserMobileBahnDe::getJourneyDetailsData - Query 1 Failed";
             }
+            qDebug() << "stationResults" << endl << stationResults;
 
             query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/a/span/string()");
 
@@ -318,6 +344,7 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
             {
                 qDebug() << "parserMobileBahnDe::getJourneyDetailsData - Query 2 Failed";
             }
+            qDebug() << "trainnrResults" << endl << trainnrResults;
 
             if (divMode==ROUTE_MOT)
             {
@@ -334,13 +361,13 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
             }
 
 
-            /*
+
             qDebug() <<num;
             qDebug() <<element;
             qDebug() <<stationResults;
             qDebug() <<trainnrResults;
             qDebug() <<txtResults;
-            */
+
 
 
 
